# Vendored packages for nvidia-stub

Rules for vendored code:
Ideally, vendored code should be completely unmodified. It should only be modified if that is needed to vendor the code.

The only vendored project at the moment is packaging:
https://github.com/pypa/packaging

Packaging is licensed under either the BSD 2-clause license or the Apache-2 license. Both are included in `_vendor/packaging/LICENSE`
